Module plugins

Module plugins 

Collection of plugins that sync additional components with PhysX engine.

These are added as a convenience, users can potentially disable them or implement their own similar plugins.

Modules

articulation
Configure articulation joints and joint drives, get/set joint positions.
damping
Set linear and angular damping coefficients for a rigid body.
debug_render
Draw debug visualization on the screen.
external_force
Continuously apply force and torque to the actor.
kinematic
Enable kinematic mode for an actor, set kinematic target.
lock_flags
mass_properties
Compute and set mass properties (mass/density, inertia, center of mass) for a rigid body.
name
Assigns a name for the object to be displayed in PVD.
shape_filter_data
Set the shape’s query and collision filter data.
shape_offsets
Set the shape’s contact offset and rest offset for collisions.
sleep
Two-way sync of sleep state, wake counter, sleep threshold, etc.
velocity
Get/set linear and angular velocity of a rigid body, set maximum velocity.